@@ -7,7 +7,7 @@ use strict;
 
 package Net::FTPSSL::Robust;
 use vars '$VERSION';
-$VERSION = '0.01';
+$VERSION = '0.02';
 
 use base 'Net::FTP::Robust', 'Exporter';
 
@@ -56,5 +56,8 @@ sub _modif_time($$)
     $ftp->_mdtm($fn);
 }
 
+# not implemented/not possible?
+sub _can_restart($$$) { 0 }
+
 
 1;
